#
# spec file for package kfilemetadata5
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.71
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without ffmpeg
%bcond_without lang
Name:           kfilemetadata5
Version:        5.71.0
Release:        lp152.1.1
Summary:        Library for extracting Metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/kfilemetadata-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/kfilemetadata-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:       baselibs.conf
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  libattr-devel
BuildRequires:  libepub-devel
BuildRequires:  libexiv2-devel >= 0.21
BuildRequires:  pkgconfig
BuildRequires:  taglib-devel >= 1.9
BuildRequires:  cmake(KF5Archive) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Test) >= 5.12.0
BuildRequires:  cmake(Qt5Xml) >= 5.12.0
BuildRequires:  pkgconfig(poppler-qt5)
Recommends:     %{name}-lang
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif

%description
A library for extracting file metadata.

%package devel
Summary:        Development package for kfilemetadata
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules >= %{_kf5_bugfix_version}
Requires:       cmake(Qt5Core) >= 5.12.0

%description devel
A library for extracting file metadata. Development files

%lang_package

%prep
%setup -q -n kfilemetadata-%{version}

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %cmake_build

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %{kf5_find_lang}
%endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING*
%{_kf5_plugindir}/
%{_kf5_libdir}/libKF5FileMetaData.so.*
%{_kf5_debugdir}/*.categories

%files devel
%license COPYING*
%{_kf5_libdir}/libKF5FileMetaData.so
%{_kf5_includedir}/KFileMetaData/
%{_kf5_libdir}/cmake/KF5FileMetaData/
%{_kf5_mkspecsdir}/qt_KFileMetaData.pri

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * [TaglibExtractor] Add support for Audible "Enhanced Audio" audio books
  * test the extractNothing flag
  * honor the extractMetaData flag
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Port away from deprecated QList::toSet() method
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * In qt5.15 QHash::insertMulti is deprecated now we need to use QMultiHash
  * Port QRegExp to QRegularExpression
  * partial fix for accentuated characters in file name on Windows
  * Port deprecated QSet::toList method
  * Update the obsolete projects.kde.org URL
  * Remove unrequired private declarations for taglibextractor
  * partial solution to accept accentuated characters on windows
  * xattr: fix crash on dangling symlinks (kde#414227)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * xattr: fix crash on dangling symlinks (kde#414227)
  * disable writercollectiontest when taglib is not installed
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Fix crash in writer collection and cleanup
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Small performance improvements suggested by clang tidy
  * Port away from deprecated QDateTime::setUtcOffset
* Wed Sep 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop Qt5Multimedia BuildRequires, not used since KF 5.41.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Implement writing of images
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * add missing semicolon
  * Get mobipocket extractor up-to-date, but keep disabled
  * taglibextractortest.cpp - fix build with include <QSet>
  * Remove unused includes
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Fix extracting of some properties to match what was written (kde#408532)
  * Use debugging category in taglib extractor/writer
  * Format photo exposure bias value
  * [XAttr] Probably fix build on Windows
  * fix property name
  * Remove photo prefix from every exif property name
  * Rename ImageMake and ImageModel properties
  * [UserMetaData] Add method to query which attributes are set
  * Format focal length as milli meter
  * Install in new logging directory when we use kf5 5.59.0
  * Format photo exposure time as rational when applicable
  * Enable usermetadatawritertest for all UNIXes, not only Linux.
  * Format the aperture values as F numbers.
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Show 3 significant figures when displaying doubles
  * clarify and document method
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Reorder includes
  * [TaglibExtractor] Feed non-ogg *.spx file into extractor test
  * [TagLibExtractor] Fix crash on invalid Speex files (kde#403902)
  * Fix exivextractor crash with malformed files (kde#405210)
  * Declare properties as meta type
  * Change properties attributes for consistency
  * Handle variant list in formatting functions
  * add license to python test files
  * Force en locale for propertyinfotest
  * Fix for Windows' stupid LARGE_INTEGER type
  * Fix (compilation) errors for Windows UserMetaData implementation
  * remove unnecessary parenthesis
  * add missing mimetype to taglib writer
  * Test all extractors with strict mime type
  * fix warnings
  * Use new mimetype helper in taglib extractor test
  * [UserMetaData] Handle changes in attribute data size correctly
  * [UserMetaData] Untangle Windows, Linux/BSD/Mac and stub code.
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Too many changes to list here
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * cleanup and slightly enhance display formatting test
  * Fix typo in exiv extractor
  * [Extractor] Add metadata to extractors
  * add test which checks the property types
  * Add extractor for AppImage files
  * Cleanup ffmpeg extractor
  * Add a test for ffmpeg extractor
  * [ExternalExtractor] Provide more helpful output when extractor fails
  * Fix minor typo
  * Format EXIF photo flash data
  * Fix build with cmake 3.5
  * Avoid side effects due to stale errno value
  * Try to fix test on windows
  * Use Kformat for bit and sample rate
  * Add units to framerate and gps data
  * Add string formatting function to property info
  * Avoid leaking a QObject in ExternalExtractor
  * Handle <a> as container element in SVG
  * Check Exiv2::ValueType::typeId before converting it to rational
- Dropped patches, now upstream:
  * fix-build-with-cmake-3.5.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Tue Feb 12 2019 wbauer@tmo.at
- Add fix-build-with-cmake-3.5.patch to fix build with cmake 3.5.2
  on Leap 42.3
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * harmonize testing data
  * exiv2extractor: add support for bmp, gif, webp, tga
  * Fix failing test of exiv gps data
  * Test empty and zero gps data
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Use more https in links
  * add support for more mimetypes to taglibwriter
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix some warnings
  * fail writing test if mime type is not supported by the extractor
  * fix ape disc number extraction
  * implement cover extraction for asf files
  * extend list of supported mimetypes for embedded image extractor
  * Refactor embedded image extractor for greater extensibility
  * add missing wav mimetype
  * Extract more tags from exif metadata (kde#341162)
  * fix extraction of GPS altitude for exif data
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Adapt to the FindExiv2 -> FindLibExiv2 name change in ECM.
  * Use the new FindExiv2 module from ECM.
  * Revive 'Description' property for DublinCore metadata
  * add a description property to KFileMetaData
  * [KFileMetaData] Add extractor for DSC conforming (Encapsulated) Postscript
  * rename variable
  * remove unneeded comment
  * cleanup the test for embedded image extraction
  * Add missing override
  * [ExtractorCollection] Avoid dependency of kcoreaddons for CI tests
  * Add support for speex files to taglibextractor
  * add two more internet sources regarding tagging information
  * fix alphabetical order
  * remove unused include
  * use qlatin1 for embedded image extractor
  * move supported mimetypes to static string list
  * create a separate test file for embedded images test
  * simplify handling of id3 tags
  * add explicit to constructors
  * add missing license information
  * [XmlExtractor] Use QXmlStreamReader for better performance
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * remove own implementation of QString to TString conversion for taglibwriter
  * increase test coverage of taglibwriter
  * implement more basic tags for taglibwriter
  * remove usage of own TString to QString conversion function
  * bump required taglib version to 1.11.1
  * implement reading of the replaygain tags
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * add missing include
  * Add enum alias Property::Language for typo Property::Langauge
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * API dox: add @file to functions-only header to have doxygen cover those
* Thu Aug  9 2018 fabian@ritter-vogt.de
- Don't recommend catdoc, doesn't exist anymore (boo#1104264)
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Avoid compiler warnings for taglib headers
  * PopplerExtractor: use directly QByteArray() args instead of 0 pointers
  * Use more nullptr
  * taglibextractor: Restore extracting audio props without tags existing
  * OdfExtractor: deal with non-common prefix names
  * Don't add -ltag to the public link interface.
  * implement the lyrics tag for taglibextractor
  * OdfExtractor: fix typo with dc:language
  * automatic tests: do not embed EmbeddedImageData already in the library
  * add ability to read embedded cover files
  * implement reading of rating tag
  * check for needed version of libavcode, libavformat and libavutil
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
  * check that ffmpeg is at least version 3.1 that introduce the API we require
  * split tests for better readability
  * search for album artist and albumartist tags in taglibextractor
  * popplerextractor: don't try to guess the title if there isn't one.
- Dropped patches, superseded by upstream changes:
  - ffmpeg-buildrequires.patch
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Add description and purpose to Xattr dep
  * extractors: Hide warnings from system headers
  * fix detection of taglib when compiling for Android
  * [API dox] Note CamelCase include commands for classes
  * Install pri file for qmake support & document it in metainfo.yaml
  * Make concatenated strings wrappable
  * ffmpegextractor: Silence deprecation warnings
  * autotests: Do not use QScopedPointer for plugins
  * taglibextractor: Fix empty genre bug
  * taglibextractortest: Add test for files with empty metadata
  * taglibextractortest: Add test for files with empty metadata
  * handle more tags in taglibextractor
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * taglibextractor: Refactor for better readability
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix build with >=attr-2.4.48
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Use more explicit
  * Use more nullptr
  * Use nullptr, const'ify, port some Q_FOREACH to for(..:..)
  * Fix build against TagLib < 1.11
  * remove extractor based on QtMultimedia
  * Check for Linux instead of TagLib and avoid building the usermetadatawritertest on Windows.
  * Restore # 6c9111a9 until a successful build and link without TagLib is possible.
  * Remove the taglib dependency, caused by a left-over include. Also reverts commit # 6c9111a9
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * The usermetadatawritertest requires Taglib. Therefore if Taglib isn't around, we shouldn't try to build something that requires it. This fixes the build on Windows.
  * Port to debug category
  * Fix UserMetaData unit tests.
  * User meta data (xattr key-value) unit tests.
  * Simplify empty rating check.
  * If the property value is null, remove the user.xdg.tag attribute. (kde#376117)
  * Open files in TagLib extractor readonly
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix display name of Generator property
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * fix crash when more than one instances of ExtractorCollection are destructed
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * in automatic tests, find python interpreter and use it for python test scripts
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix Python dependency in test scripts for KFileMetaData (bug 375472)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix configure with Qt5Multimedia disabled.
  * add an extractor using qtmultimedia
  * [FEATURE] Option to build & install QCH file with the public API dox
  * fix warnings from clazy with the default warning level
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * use /usr/bin/env to locate python2
  * Use right QProcess API
  * fix build against Android NDK (API Level 21 is required)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Rename the translation template (avoid conflicts)
  * makes KArchive be optional and do not build extractors needing it
  * cmake: switch to the FindPoppler module from ECM
  * fix duplicated symbols compilation error with mingw on Windows
  * autotests: Use QTEST_GUILESS_MAIN
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Make PlainTextExtractor match "text/plain" again
  * Upgrade KF5 version to 5.33.0.
- Remove patches, now upstream:
  * Make-PlainTextExtractor-match-text-plain-again.patch
* Mon Mar 20 2017 wbauer@tmo.at
- Add Make-PlainTextExtractor-match-text-plain-again.patch to fix
  metadata extraction for text files which got broken in 5.32.0
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
  * fix build of kfilemetadata with taglib version 1.9
  * New maintainer for kfilemetadata
  * [ExtractorCollection] Use mimetype inheritance to return plugins
  * add a new property DiscNumber for audio files from multi-disc albums
  * add more audio format to automatic test and fix problems
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Actually find FFMpeg's libpostproc
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Improve epub extractor, less segfaults (kde#361727)
  * Make odf indexer more error prove, check if the files are there
    (and are files at all) (meta.xml + content.xml)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Only require Xattr if the operating system is Linux
  * Restore Windows build
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Check for xattr during config step, otherwise the build
    might fail (if xattr.h is missing)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Fixed external plugins and tests
  * Added support for external writer plugins
  * Added writer plugin support
  * Add external extractor plugin support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Sun Apr 17 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
  ffmpeg-buildrequires.patch
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * KFileMetadata can now query and store information about the
    original email a saved file may have been an attachment of
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Allow querying for a file's origin URL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Mon Jan 11 2016 wbauer@tmo.at
- Build against poppler-qt5 on SLE12 and Leap 42 as well, it is
  available meanwhile (boo#953957)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Mark m4a as readable by taglib
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Implement windows usermetadata
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * PlainTextExtractor: enable O_NOATIME branch on GNU libc platforms
  * PlainTextExtractor: make the Linux branch work also without O_NOATIME
  * PlainTextExtractor: fix error check on open(O_NOATIME) failure
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Fri Sep  4 2015 hrvoje.senjan@gmail.com
- Only Recommend catdoc, to help reducing liveCD/DVD size
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Mon Jul 20 2015 mlin@suse.com
- No poppler-qt5 in Leap 42, do not build with it on 42 and SLE
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Update required taglib version to 1.9
- Added libattr-devel BuildRequires
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Enable ffmpeg support on openSUSE > 13.2
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Add lang subpackage
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Unconditionally BuildRequire pkgconfig(poppler-qt5)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API adjustements since previous snapshot
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140911 (r5d1c60d):
  * Use QPluginLoader instead of KService for loading the plugins.
  * API cleanups
- Drop kservice-devel BuildRequires, per upstream changes
- Add baselibs.conf
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0
  * Beta 2 of Plasma 5 release
- Add Source URL
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Activate kfilemetadata5 package
